function h = scDraw(ChColor)

% DEFINE STANDARD DEFAULT FOR r
r= [0.5, 1, 2];
rPrint = [0.5,1,2];
    
% DEFINE STANDARD DEFAULT FOR x
x= [0.5, 1, 2];
xPrint  = [0.1:0.1:1.0,1.5 2.0 3.0 4.0 5.0 10 20 50];
    
rR = zeros(size(x));
rL = zeros(size(x));
xR = zeros(size(r));
xL = zeros(size(r));
   
%ChColor = 'r';

% DRAW r CIRCLES
scResCirc(r, ChColor, xR, xL);
axis equal;
axis on;
axis([-1 1 -1 1])

% DRAW x ARCS
scReacArc(x, 1, ChColor, rR, rL);
scReacArc(x, -1, ChColor, rR, rL);

% DRAW THE OUTER CIRCLE AND THE X-AXIS
plot([-1 1],[0 0], ChColor);
plot(-1:.001:1, sqrt(1-(-1:.001:1).^2), ChColor);
plot(-1:.001:1,-sqrt(1-(-1:.001:1).^2), ChColor);
    
% PRINT r VALUES
%scPrnVal(rPrint, 'r');
    
% PRINT x VALUES
%scPrnVal(xPrint, 'x');







function scResCirc(r, LinCol, xR, xL)
% scResCirc: draws r circles in the smith chart

for ii = 1:length(r)
    rc = r(ii);
    if xR(ii)~=0
        xc1 = xR(ii);
        [xco1, yco1] = scPOI(rc, xc1);
    else
        xco1 = 1;
    end
    
    if xL(ii)~=0
        [xco2, yco2] = scPOI(rc, xL(ii));
    else
        xco2 = 20;
    end
    if xco1 < xco2
        u      = linspace((rc-1)/(rc+1), xco1, 500);
        vplus  = sqrt((1/(1+rc))^2-(u-rc/(1+rc)).^2);
        vminus = (-sqrt((1/(1+rc))^2-(u-rc/(1+rc)).^2));
        plot(real(u),real(vplus),LinCol);
        hold on;
        plot(real(u),real(vminus),LinCol);
    end
    if xco2 ~= 20
        u      = linspace(xco2, xco1, 200);
        vplus  = sqrt((1/(1+rc))^2-(u-rc/(1+rc)).^2);
        vminus = (-sqrt((1/(1+rc))^2-(u-rc/(1+rc)).^2));
        plot(real(u),real(vplus),LinCol);
        hold on;
        plot(real(u),real(vminus),LinCol);
    end
end

function scReacArc(x,updown,LinCol,rR, rL)
%scReacArc: draws x arcs in the smith chart

for jj=1:length(x)
    xc     = x(jj);
    if rR(jj)~=0
        rc1 = rR(jj);
        [xco1, yco1] = scPOI(rR(jj), xc);
    else
        xco1 = 1;
        yco1 = 0;
    end
    
    if rL(jj)~=0
        [xco2, yco2] = scPOI(rL(jj), xc);
    else
        xco2 = 20;
        yco2 = 0;
    end
    if xco1 < xco2 && xc~=0
        % FOR THE ARCS STARTING FROM THE OUTERMOST CIRCLE
        if xc <= 1
            % IF THE 9'O CLOCK POS. OF THE X ARC DOES NOT LIE WITHIN THE SMITH CHART
            uup = [];
            vup = [];
            udn = linspace((xc^2-1)/(xc^2+1), xco1, 500);
            vdn = sign(updown)*(1/xc-sqrt((1/xc)^2-(udn-1).^2));
            
        elseif (1/xc-sqrt((1/xc)^2-(1-1/xc-1).^2)) < yco1
            % IF THE 9'O CLOCK POS. OF THE X ARC  IS LOWER THAN POINT OF INTERSECTION
            uup = linspace(xco1,(xc^2-1)/(xc^2+1),100);
            vup = sign(updown)*(1/xc+sqrt(1/xc^2-(uup-1).^2));
            udn = [];
            vdn = [];
        else
            % IF THE 9'O CLOCK POS. OF THE X ARC  IS HIGHER THAN POINT OF INTERSECTION
            uup = linspace(1-1/xc,(xc^2-1)/(xc^2+1),100);
            vup = sign(updown)*(1/xc+sqrt(1/xc^2-(uup-1).^2));
            udn = linspace(1-1/xc,xco1,500);
            vdn = sign(updown)*(1/xc-sqrt((1/xc)^2-(udn-1).^2));
        end
    end
    if xco2~=20 && xc~=0
        if (1/xc-sqrt((1/xc)^2-(1-1/xc-1).^2)) > yco2
            uup = [];
            vup = [];
            udn = linspace(xco2, xco1, 500);
            vdn = sign(updown)*(1/xc-sqrt((1/xc)^2-(udn-1).^2));
        else
            % IF THE 9'O CLOCK POS. OF THE X ARC  IS LOWER THAN POINT OF INTERSECTION
            uup = linspace(1-1/xc,xco2,100);
            vup = sign(updown)*(1/xc+sqrt(1/xc^2-(uup-1).^2));
            udn = linspace(1-1/xc,xco1,500);
            vdn = sign(updown)*(1/xc-sqrt((1/xc)^2-(udn-1).^2));
        end
    end
    if xc~=0
        plot(real(uup),real(vup),LinCol);
        plot(real(udn),real(vdn),LinCol);
    end
end

function scPrnVal(vPrn, rORx)
%scPrnVal: Prints x and r values on the smith chart

if rORx == 'x'
    % PRINT x VALUES
    for jj = 1 : length(vPrn)
        xc   = vPrn(jj);
        [xco1, yco1] = scPOI(0, xc);
        [xco2, yco2] = scPOI(1, xc);
        
        if floor(xc)==xc && length(num2str(floor(xc)))>=2
            PrStr='%0.0f';
        else
            PrStr='%0.1f';
        end
        
        h = text (min(xco1), max(yco1), num2str(xc,PrStr));
        set(h,'color','r', 'rotation', 180*atan2(1-min(xco1), max(yco1)-abs(1/xc))/pi, 'fontsize', 4.5, 'HorizontalAlignment', 'right', 'VerticalAlignment', 'bottom');
        
        h = text (min(xco1), -max(yco1), num2str(xc, PrStr));
        set(h,'color','r', 'rotation', 180+180*atan2(-1+min(xco1), max(yco1)-abs(1/xc))/pi, 'fontsize', 4.5, 'HorizontalAlignment', 'left', 'VerticalAlignment', 'bottom');
        if xc <=1
            h = text (min(xco2), -max(yco2), num2str(xc, PrStr));
            set(h,'color','r', 'rotation', 180+180*atan2(-1+min(xco2), max(yco2-abs(1/xc)))/pi, 'fontsize', 4.5, 'HorizontalAlignment', 'left', 'VerticalAlignment', 'bottom');
            
            h = text (min(xco2), max(yco2), num2str(xc, PrStr));
            set(h,'color','r', 'rotation', 180*atan2(1-min(xco2), max(yco2)-abs(1/xc))/pi, 'fontsize', 4.5, 'HorizontalAlignment', 'right', 'VerticalAlignment', 'bottom');
        end
    end
elseif rORx == 'r'
    % PRINT r VALUES
    for jj = 1 : length(vPrn)
        rc   = vPrn(jj);
        xco1 = (rc-1)/(rc+1);
        yco1 = 0.01;
        [xco2, yco2] = scPOI(rc, 1);
        if floor(rc)==rc && length(num2str(floor(rc)))>=2
            PrStr='%0.0f';
        else
            PrStr='%0.1f';
        end
        h = text (xco1, yco1, num2str(rc,PrStr));
        set(h,'color','r','rotation',90,'fontsize',4.5,'HorizontalAlignment','left', 'VerticalAlignment', 'bottom');
        if rc <= 1
            h = text (xco2, yco2, num2str(rc,PrStr));
            set(h,'color','r','rotation',180*atan2(rc/(1+rc)-xco2, yco2)/pi, 'fontsize',4.5,'HorizontalAlignment','left', 'VerticalAlignment', 'bottom');
            h = text (xco2, -yco2, num2str(rc,PrStr));
            set(h,'color','r','rotation', 180+180*atan2(rc/(1+rc)-xco2, -yco2)/pi, 'fontsize',4.5,'HorizontalAlignment','left', 'VerticalAlignment', 'bottom');
        end
    end
else
    error('scPrnVal.m: The second argument must either be r or x');
end




